# BLImPy 2.0

[![DOI](https://zenodo.org/badge/15832380.svg)](https://zenodo.org/badge/latestdoi/15832380)

BLImPy (Basic List Implementation in Python) is a basic implementation of a
linked list data structure that is a drop-in replacement for the Python list.
It supports all basic list methods. The data structure is not as efficient as
the Python list for many operations and in most cases, should not be used
except in a teaching setting. It was developed to illustrate basic principles
and to be used with GiMPy, a graph implementation in Python. BLImPy includes a
stack data structure, a queue data structure, and a priority queue data
structure.

Install with
```
pip install coinor.blimpy
```

Documentation for the API is here:

http://tkralphs.github.io/BLImPy/

PyPi download page is here:

https://pypi.python.org/pypi/coinor.gimpy
